
# Slot: entries




URI: [nwb_schema_language:namespacesCollection__entries](https://w3id.org/p2p_ld/nwb-schema-language/namespacesCollection__entries)


## Domain and Range

None &#8594;  <sub>0..\*</sub> [Namespaces](Namespaces.md)

## Parents


## Children


## Used by

 * [NamespacesCollection](NamespacesCollection.md)
